@@ -6,6 +6,30 @@
 
 G_BEGIN_DECLS
 
+#if GTK_CHECK_VERSION (3, 2, 0)
+    #define GTK_TYPE_VBOX GTK_TYPE_BOX
+    #define GtkVBox GtkBox
+    #define GtkVBoxClass GtkBoxClass
+    #define gtk_vbox_new(hmg,spc) g_object_new (GTK_TYPE_BOX, \
+        "homogeneous", hmg, "spacing", spc, \
+        "orientation", GTK_ORIENTATION_VERTICAL, NULL)
+    #define GTK_TYPE_HBOX GTK_TYPE_BOX
+    #define GtkHBox GtkBox
+    #define GtkHBoxClass GtkBoxClass
+    #define gtk_hbox_new(hmg,spc) g_object_new (GTK_TYPE_BOX, \
+        "homogeneous", hmg, "spacing", spc, \
+        "orientation", GTK_ORIENTATION_HORIZONTAL, NULL)
+    #define gtk_hseparator_new() g_object_new (GTK_TYPE_SEPARATOR, NULL)
+    #define gtk_hpaned_new() g_object_new (GTK_TYPE_PANED, NULL)
+    #define gtk_vpaned_new() g_object_new (GTK_TYPE_PANED, \
+        "orientation", GTK_ORIENTATION_VERTICAL, NULL)
+    /* FIXME */
+    #define gtk_widget_render_icon(wdgt, stk, sz, dtl) \
+        gtk_widget_render_icon_pixbuf(wdgt, stk, sz)
+    #define gtk_widget_size_request(wdgt, req) \
+        gtk_widget_get_preferred_size(wdgt, req, NULL)
+#endif
+
 #if !GLIB_CHECK_VERSION (2, 32, 0)
     #define G_SOURCE_REMOVE   FALSE
     #define G_SOURCE_CONTINUE TRUE
