@@ -9,6 +9,12 @@
  See the file COPYING for the full license text.
 */
 
+/* When cross-compiling assume at least WinXP */
+#ifdef _WIN32
+    #define _WIN32_WINNT 0x0501
+    #include <unistd.h>
+#endif
+
 #if HAVE_CONFIG_H
     #include <config.h>
 #endif
@@ -37,7 +43,13 @@
 #elif HAVE_UNIQUE
     typedef gpointer MidoriAppInstance;
     #define MidoriAppInstanceNull NULL
+    #if defined(G_DISABLE_DEPRECATED) && !defined(G_CONST_RETURN)
+        #define G_CONST_RETURN
+    #endif
     #include <unique/unique.h>
+    #ifdef G_DISABLE_DEPRECATED
+        #undef G_CONST_RETUTN
+    #endif
     #define MIDORI_UNIQUE_COMMAND 1
 #else
     typedef gint MidoriAppInstance;
@@ -315,7 +327,7 @@ midori_app_class_init (MidoriAppClass* class)
                                      "name",
                                      "Name",
                                      "The name of the instance",
-                                     "midori",
+                                     NULL,
                                      G_PARAM_CONSTRUCT_ONLY |
                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
@@ -494,9 +506,7 @@ midori_app_command_received (MidoriApp*   app,
             first = (open_external_pages_in == MIDORI_NEW_PAGE_CURRENT);
             while (*uris)
             {
-                gchar* fixed_uri = sokoke_magic_uri (*uris);
-                if (!fixed_uri)
-                    fixed_uri = g_strdup (*uris);
+                gchar* fixed_uri = g_uri_unescape_string (*uris, NULL);
                 if (sokoke_recursive_fork_protection (fixed_uri, FALSE))
                 {
                     if (first)
@@ -1431,5 +1441,28 @@ midori_app_setup (gchar** argument_vector)
     gtk_icon_factory_add_default (factory);
     g_object_unref (factory);
     #endif
+
+    /* Print messages to stdout on Win32 console, cf. AbiWord
+     * http://svn.abisource.com/abiword/trunk/src/wp/main/win/Win32Main.cpp */
+    #ifdef _WIN32
+    if (fileno (stdout) != -1
+    && _get_osfhandle (fileno (stdout)) != -1)
+    {
+        /* stdout is already being redirected to a file */
+    }
+    else
+    {
+        typedef BOOL (WINAPI *AttachConsole_t) (DWORD);
+        AttachConsole_t p_AttachConsole =
+            (AttachConsole_t) GetProcAddress (GetModuleHandle ("kernel32.dll"), "AttachConsole");
+        if (p_AttachConsole != NULL && p_AttachConsole (ATTACH_PARENT_PROCESS))
+        {
+            freopen ("CONOUT$", "w", stdout);
+            dup2 (fileno (stdout), 1);
+            freopen ("CONOUT$", "w", stderr);
+            dup2 (fileno (stderr), 2);
+        }
+    }
+    #endif
 }
 
