@@ -20,11 +20,11 @@
 #include "midori-panel.h"
 #include "midori-preferences.h"
 #include "midori-searchaction.h"
-#include "midori-stock.h"
 #include "midori-view.h"
 #include "midori-viewable.h"
 #include "midori-websettings.h"
 #include "midori-platform.h"
+#include <midori/midori-core.h> /* Vala API */
 
 /* For convenience, include localization header */
 #include <glib/gi18n-lib.h>
