@@ -55,11 +55,6 @@ sokoke_external_uri                     (const gchar*    uri);
 gchar*
 sokoke_magic_uri                        (const gchar*    uri);
 
-void
-sokoke_combo_box_add_strings            (GtkComboBox*    combobox,
-                                         const gchar*    label_first,
-                                         ...);
-
 void
 sokoke_widget_set_visible               (GtkWidget*      widget,
                                          gboolean        visible);
