@@ -9,13 +9,7 @@
  See the file COPYING for the full license text.
 */
 
-#if HAVE_CONFIG_H
-    #include <config.h>
-#endif
-
 #include "midori.h"
-#include "midori-stock.h"
-#include "sokoke.h"
 
 static void
 browser_create (void)
@@ -49,18 +43,69 @@ browser_create (void)
     g_object_unref (app);
 }
 
+static void
+browser_tooltips (void)
+{
+    MidoriBrowser* browser;
+    GtkActionGroup* action_group;
+    GList* actions;
+    gchar* toolbar;
+    guint errors = 0;
+
+    browser = midori_browser_new ();
+    action_group = midori_browser_get_action_group (browser);
+    actions = gtk_action_group_list_actions (action_group);
+    toolbar = g_strjoinv (" ", (gchar**)midori_browser_get_toolbar_actions (browser));
+
+    while (actions)
+    {
+        GtkAction* action = actions->data;
+        const gchar* name = gtk_action_get_name (action);
+
+        if (strstr ("CompactMenu Location Separator", name))
+        {
+            actions = g_list_next (actions);
+            continue;
+        }
+
+        if (strstr (toolbar, name) != NULL)
+        {
+            if (!gtk_action_get_tooltip (action))
+            {
+                printf ("'%s' can be toolbar item but tooltip is unset\n", name);
+                errors++;
+            }
+        }
+        else
+        {
+            if (gtk_action_get_tooltip (action))
+            {
+                printf ("'%s' is no toolbar item but tooltip is set\n", name);
+                errors++;
+            }
+        }
+        actions = g_list_next (actions);
+    }
+    g_free (toolbar);
+    g_list_free (actions);
+    gtk_widget_destroy (GTK_WIDGET (browser));
+
+    if (errors)
+        g_error ("Tooltip errors");
+}
+
 int
 main (int    argc,
       char** argv)
 {
-    /* libSoup uses threads, therefore if WebKit is built with libSoup
-       or Midori is using it, we need to initialize threads. */
-    if (!g_thread_supported ()) g_thread_init (NULL);
+    midori_app_setup (argv);
+    g_object_set_data (G_OBJECT (webkit_get_default_session ()),
+                       "midori-session-initialized", (void*)1);
     g_test_init (&argc, &argv, NULL);
     gtk_init_check (&argc, &argv);
-    sokoke_register_stock_items ();
 
     g_test_add_func ("/browser/create", browser_create);
+    g_test_add_func ("/browser/tooltips", browser_tooltips);
 
     return g_test_run ();
 }
